Registration

Struct Registration 

pub struct Registration { /* private fields */ }
A registration for an OpenC2 consumer, with the action/target pairs it wishes to handle.

The registration is the “key” in a Registry, with a Consume implementer as the “value”. The Registry handles indexing of registrations to efficiently route commands to the appropriate consumer.

Implementations

Source

impl Registration

pub fn new() -> Self

pub fn with_actions( self, actions: impl IntoIterator<Item = (Nsid, Action, TargetType<'static>)>, ) -> Self

pub fn with_actions_without_profile( self, actions: impl IntoIterator<Item = (Action, TargetType<'static>)>, ) -> Self

pub fn profiles(&self) -> impl Iterator<Item = &Nsid>

Returns the profiles this consumer supports. This could be empty if the consumer only supports actions without profiles.

pub fn matches( &self, action: Action, target: &TargetType<'_>, profile: &Nsid, ) -> bool

Checks if this registration matches the given action, target type, and profile.

pub fn query_features(&self, features: &Features) -> Response