Modules
Structs
- Registration
- A registration for an OpenC2 consumer, with the action/target pairs it wishes to handle.
- Registry
- An OpenC2 consumer made up of more specific consumers that share a single
toaddress.
Traits
- Consume
- Consumer trait for handling OpenC2 messages.
- ToRegistration
- Trait for producing a registration, typically from a consumer.
Type Aliases
- BoxConsumer
- An async-friendly boxed
Consumetrait object.