pub struct Registration { /* private fields */ }Expand description
Implementations
Sourceimpl Registration
impl Registration
pub fn new() -> Self
pub fn with_actions( self, actions: impl IntoIterator<Item = (Nsid, Action, TargetType<'static>)>, ) -> Self
pub fn with_actions_without_profile( self, actions: impl IntoIterator<Item = (Action, TargetType<'static>)>, ) -> Self
Sourcepub fn profiles(&self) -> impl Iterator<Item = &Nsid>
pub fn profiles(&self) -> impl Iterator<Item = &Nsid>
Returns the profiles this consumer supports. This could be empty if the consumer only supports actions without profiles.
Sourcepub fn matches(
&self,
action: Action,
target: &TargetType<'_>,
profile: &Nsid,
) -> bool
pub fn matches( &self, action: Action, target: &TargetType<'_>, profile: &Nsid, ) -> bool
Checks if this registration matches the given action, target type, and profile.
pub fn query_features(&self, features: &Features) -> Response